#!/usr/bin/env python
'''plot relation between cscore and precision'''
import matplotlib
matplotlib.use("agg")
from matplotlib import pylab as plt
import numpy as np

def load_cscore_txt(cscore_file):
    '''load cscore table'''
    fp=open(cscore_file,'rU')
    lines=fp.read().splitlines()[:-1] # last row is correlation coefficient
    fp.close()
    data=np.zeros([len(lines),3])
    for idx,line in enumerate(lines):
        cscore_range,precision=line.split()
        cscore_lower=float(cscore_range.split('<')[0].strip('='))
        cscore_upper=float(cscore_range.split('<')[-1].strip('='))
        data[idx,:]=[float(cscore_lower),float(cscore_upper),float(precision)]
    return data

category_list=["GO","EC","LBS"]
aspect_dict={
    "GO":["MF","BP","CC"],
    "EC":["1","2","3","4"],
    "LBS":["LBS"]
}
title_list=["(A)","(B)","(C)"]
width = 0.27       # the width of the bars
color_list=['#55AAFF','#FFAA55','#AAAAAA','y']

aspect_name_dict={
    "EC":["first digit","first 2 digits","first 3 digits","all 4 digits"]
}

fig=plt.figure(figsize=(16,12))
#fig_subplot,axes = plt.subplots(nrows=2, ncols=2)
#fig_subplot.tight_layout()
#plt.subplots_adjust(wspace = 2)
for i,category in enumerate(category_list):
    ax = fig.add_subplot(2,2,i+1)

    rects=[]
    aspect_list=aspect_dict[category]
    for a,aspect in enumerate(aspect_list):
        data=load_cscore_txt("cscore."+aspect)
        ind=np.arange(data.shape[0])
        rects.append(ax.bar(ind+(0.35+a)*width*3/len(aspect_list), 
            data[:,2], width*3/len(aspect_list),
            color=color_list[a],edgecolor=''))

    xticks_labels=[]
    for cscore in ind:
        xticks_labels.append("(%.1f,%.1f]"%(data[cscore,0],data[cscore,1]))

    #ax.axis('tight')
    ax.set_xlabel('cscore '+category,fontsize=20)
    ax.set_ylabel('precision',fontsize=18)
    ax.set_xticks(ind+width*1.8)
    ax.set_xticklabels(xticks_labels)
    if len(aspect_list)>1:
        if category in aspect_name_dict:
            ax.legend( aspect_name_dict[category],loc='best')
        else:
            ax.legend( aspect_list,loc='best')
    plt.title(title_list[i],fontsize=20)

    plt.tight_layout(pad=0.4, w_pad=0.5, h_pad=1.0)

for outfmt in ["eps","svg","png"]:
    plt.savefig('cscore.'+outfmt,dpi=400)
plt.close()
