#!/usr/bin/env python
'''blast-GOfreq,psiblast-GOfreq,combine-GOfreq vs seqID cutoff'''
import matplotlib
matplotlib.use("agg")
from matplotlib import pylab as plt

seqID_list=[0.2,0.3,0.5,0.9]
dataset={
    'COFACTOR':{
        'MF':[0.5816,0.6110,0.6326,0.6400],
        'BP':[0.5592,0.5789,0.6023,0.6018],
        'CC':[0.5412,0.5819,0.6032,0.6073],
    },
    'structure':{
        'MF':[0.5379,0.5409,0.5410,0.5407],
        'BP':[0.4960,0.4950,0.4961,0.4967],
        'CC':[0.5116,0.5130,0.5144,0.5133],
    },
    'sequence':{
        'MF':[0.4353,0.5308,0.5978,0.6169],
        'BP':[0.3872,0.4787,0.5401,0.5683],
        'CC':[0.4229,0.5334,0.5717,0.5856],
    },
    'PPI':{
        'MF':[0.2425,0.2449,0.2453,0.2453],
        'BP':[0.4315,0.4318,0.4323,0.4323],
        'CC':[0.5259,0.5265,0.5269,0.5270],
    },
    'GoFDR':{
        'MF':[0.4611,0.5194,0.5603,0.6074],
        'BP':[0.4135,0.4635,0.5047,0.5475],
        'CC':[0.3762,0.4189,0.4258,0.4436],
    },
    'PSIBLAST':{
        'MF':[0.3315,0.4021,0.4829,0.5482],
        'BP':[0.2424,0.2942,0.3773,0.4971],
        'CC':[0.2672,0.3159,0.3436,0.4297],
    },
    'BLAST':{
        'MF':[0.0192,0.3787,0.4812,0.5496],
        'BP':[0.0147,0.2656,0.3644,0.5026],
        'CC':[0.0136,0.2880,0.3437,0.4282],
    },
    'Naive':{
        'MF':[0.1970]*len(seqID_list),
        'BP':[0.3169]*len(seqID_list),
        'CC':[0.4451]*len(seqID_list),
    },
}

method_list=["COFACTOR","structure","sequence","PPI","GoFDR","PSIBLAST","BLAST","Naive"]
method_dict={
    "COFACTOR":"COFACTOR",
    "structure":"structure component of COFACTOR",
    "sequence" :"sequence component of COFACTOR",
    "PPI"      :"PPI component of COFACTOR",
    "GoFDR":"GoFDR",
    "PSIBLAST":"PSIBLAST",
    "BLAST":"BLAST",
    "Naive":"Naive"}

marker_list=[
    'o',
    'v',
    '^',
    '*', # PPI
    '<',
    '>',
    's',
    '', # Naive
    '8',
    'p',
    'h',
    'H',
    'D',
    'd',
]

linestyle=["-",":",":",":","-","-","-","-"]

color_list=[
    'k', # COFACTOR
    'r', # structure
    'b', # sequence
    'g', # PPI
    'm', # GoFDR
    'c', # PISBLAST
    'y', # BLAST
    '0.5', # Naive
]
lw=2

Aspect_list=["MF","BP","CC"]
namespace_dict={'MF':"Molecular Function",'BP':"Biological Process",'CC':"Cellular Component"}

fig=plt.figure()
fig_subplot,axes = plt.subplots(nrows=2, ncols=2)
fig_subplot.tight_layout()
plt.subplots_adjust(wspace = 2)
for i,Aspect in enumerate(Aspect_list):
    plt.subplot(2,2,i+1,
        #aspect='equal'
    )
    for m,method in enumerate(method_list):
        print color_list[m]+marker_list[m]+linestyle[m]
        plt.plot(seqID_list,dataset[method][Aspect],color_list[m],
            marker=marker_list[m],linestyle=linestyle[m],
            lw=lw)
    plt.title(Aspect)
    plt.axis([0.15,0.95,0,0.7])
    plt.xlabel("sequence identity cut-off")
    plt.ylabel("Fmax")
    plt.gca().axes.get_xaxis().set_ticks(seqID_list) 

ax=plt.subplot(2,2,4)
for m,method in enumerate(method_list):
    pl=plt.plot([0.5,0.5],[0.5,0.5], color_list[m],
        marker=marker_list[m],linestyle=linestyle[m], lw=lw*1.5, 
        #label=method_dict[method],
        label=method,
        )
    #pl.set_visible(False)
plt.gca().axes.get_xaxis().set_visible(False)
plt.gca().axes.get_yaxis().set_visible(False)
for border in ["left","right","top","bottom"]:
    ax.spines[border].set_visible(False)
lg=plt.legend(loc="center",fontsize=11)
lg.draw_frame(False)
pl=plt.plot([0.5,0.5],[0.5,0.5], "ws", mec="w",mew=1)

plt.tight_layout(pad=0.4, w_pad=0.5, h_pad=1.0)
plt.savefig("plotseqID.eps",dpi=500)
plt.savefig("plotseqID.svg",dpi=500)
plt.savefig("plotseqID.png",dpi=400)
plt.close()
